package de.intevation.mxd.reader;

import org.apache.log4j.Logger;

import com.esri.arcgis.display.ISymbol;
import com.esri.arcgis.display.ILineSymbol;
import com.esri.arcgis.display.MultiLayerLineSymbol;

import org.w3c.dom.Element;

/**
 * Reads multi layer line symbol information.
 *
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public class MultiLayerLineSymbolReader
extends AbstractSymbolReader {

    /**
     * The logger.
     */
    private static final Logger logger =
        Logger.getLogger(MultiLayerLineSymbolReader.class);

    /**
     * Private member.
     */
    private MultiLayerLineSymbol symbol;

    public MultiLayerLineSymbolReader(ISymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof MultiLayerLineSymbol) {
            this.symbol = (MultiLayerLineSymbol)symbol;
        }
        else {
            throw new Exception("Not a MultiLayerLineSymbol!");
        }
    }

    public MultiLayerLineSymbolReader(ILineSymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof MultiLayerLineSymbol) {
            this.symbol = (MultiLayerLineSymbol)symbol;
        }
        else {
            throw new Exception("Not a MultiLayerLineSymbol!");
        }
    }

    /**
     * Reads the symbol attributes.
     *
     * @return The XML node.
     */
    public Element read()
    throws Exception {
        logger.debug("read()");
        for(int i = 0; i < symbol.getLayerCount(); i++) {
            ISymbol sym = (ISymbol)symbol.getLayer(i);
            ISymbolReader sreader = new LineSymbolReader(sym);
            sreader.setParent(parent);
            sreader.setUtil(util);
            sreader.read();
        }
        return parent;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
